## cdist-type__postgres_role(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__postgres_role - manage postgres roles

## 2. DESCRIPTION

This cdist type allows you to create or drop postgres roles.

## 3. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"

All other parameters map directly to the corresponding postgres createrole parameters.

password
  BOOLEAN PARAMETERS

    All parameter map directly to the corresponding postgres createrole
    parameters.

    login::
    createdb::
    createrole::
    superuser::
    inherit::

    EXAMPLES

    __postgres_role myrole

    __postgres_role myrole --password 'secret'

    __postgres_role admin --password 'very-secret' --superuser

    __postgres_role dbcustomer --password 'bla' --createdb

## 4. SEE ALSO

- cdist-type(7)
- cdist-type__postgres_database(7)
- http://www.postgresql.org/docs/current/static/sql-createrole.html

## 5. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).